@@ -10,6 +10,7 @@ import logging
 
 from jss.connection import JssClient
 
+logger = logging.getLogger(__name__)
 
 class Storage(driver.Base):
 
@@ -18,10 +19,10 @@ class Storage(driver.Base):
         self._secret_key = config.jss_secretkey
         self._bucket = config.jss_bucket
         self._domain = config.jss_domain
-        print "==========================>access_key:"+config.jss_accesskey
-        print "==========================>jss_secretkey:"+config.jss_secretkey
-        print "==========================>jss_bucket:"+config.jss_bucket
-        print "==========================>jss_domain:"+config.jss_domain
+        logger.info("==========================>access_key:%s" % config.jss_accesskey)
+        logger.info("==========================>jss_secretkey:%s" % config.jss_secretkey)
+        logger.info("==========================>jss_bucket:%s" % config.jss_bucket)
+        logger.info("==========================>jss_domain:%s" % config.jss_domain)
         
         self._jss = JssClient(None, self._access_key, self._secret_key, self._domain, None)
         
@@ -31,7 +32,7 @@ class Storage(driver.Base):
         return path
 
     def content_redirect_url(self, path):
-        print "content_redirect_url path:"+path
+        logger.info("content_redirect_url path:%s" % path)
         path = self._init_path(path)
         object_instance = self._jss.bucket(self._bucket).object(path)
         
@@ -45,7 +46,7 @@ class Storage(driver.Base):
             
     @lru.get
     def get_content(self, path):
-        print "get_content path:"+path
+        logger.info("get_content path:%s" % path)
         path = self._init_path(path)
         output = StringIO.StringIO()
         try:
@@ -61,14 +62,13 @@ class Storage(driver.Base):
             return output.getvalue()
         except Exception as e:
             print e
-            return ""
         finally:
             output.close()
 
     
     @lru.set
     def put_content(self, path, content):
-        print "put_content path:"+path
+        logger.info("put_content path:%s" % path)
         path = self._init_path(path)
         try:
             object_instance = self._jss.bucket(self._bucket).object(path)
@@ -79,7 +79,7 @@ class Storage(driver.Base):
         return path
 
     def stream_write(self, path, fp):
-        print "stream_write path:"+path
+        logger.info("stream_write path:%s" % path)
         path = self._init_path(path)
         part_size = 5 * 1024 * 1024
         if self.buffer_size < part_size:
@@ -93,7 +93,7 @@ class Storage(driver.Base):
 
     @lru.remove
     def remove(self, path):
-        print "remove path:"+path
+        logger.info("remove path:%s" % path)
         path = self._init_path(path)
 
         try:
